@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.13 2004/06/10 01:28:52 adamh Exp $
+ *  $Id: sgml-validator.c,v 1.13.2.4 2004/10/11 17:27:11 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,12 +27,15 @@
 #include "opensp/validate.h"
 
 #include <epiphany/ephy-embed-persist.h>
+#include <epiphany/ephy-embed-factory.h>
+
 #include "ephy-file-helpers.h"
 #include "ephy-debug.h"
 
 #include "mozilla-helpers.h"
 
 #include <unistd.h>
+#include <string.h>
 
 #include <glib/gi18n-lib.h>
 
@@ -132,7 +135,7 @@ sgml_validator_class_init (SgmlValidatorClass *klass)
 static void
 sgml_validator_init (SgmlValidator *validator)
 {
-	LOG ("SgmlValidator initializing %x", validator)
+	LOG ("SgmlValidator initializing %p", validator)
 
 	validator->priv = SGML_VALIDATOR_GET_PRIVATE (validator);
 }
@@ -142,7 +145,7 @@ sgml_validator_finalize (GObject *object)
 {
 	SgmlValidatorPrivate *priv = SGML_VALIDATOR_GET_PRIVATE (SGML_VALIDATOR (object));
 
-	LOG ("SgmlValidator finalizing %x", object)
+	LOG ("SgmlValidator finalizing %p", object)
 
 	g_object_unref (priv->error_viewer);
 
@@ -153,7 +156,6 @@ static gpointer
 opensp_thread (gpointer data)
 {
 	char *summary, *complete, *errors;
-	char *real_dest;
 	OpenSPThreadCBData *osp_data;
 
 	osp_data = (OpenSPThreadCBData *) data;
@@ -269,8 +271,8 @@ convert_to_utf8 (const char *file,
 	char *encoding;
 	char *base;
 	char *buf;
-	int buf_size = 4096;
-	int len;
+	gsize buf_size = 4096;
+	gsize len;
 	GIOChannel *in;
 	GIOChannel *out;
 	GIOStatus status;
@@ -325,7 +327,7 @@ save_source_completed_cb (EphyEmbedPersist *persist,
 			  SgmlValidator *validator)
 {
 	const char *dest;
-	const char *location;
+	char *location;
 	char *dest_utf8;
 	gboolean is_xml;
 	unsigned int num_errors = 0;
@@ -406,7 +408,7 @@ save_source_completed_cb (EphyEmbedPersist *persist,
 
 	data = g_new0 (OpenSPThreadCBData, 1);
 	data->dest = dest_utf8;
-	data->location = ephy_embed_get_location (embed, FALSE);
+	data->location = location;
 	g_object_ref (validator);
 	data->validator = validator;
 	data->is_xml = is_xml;
@@ -492,7 +494,7 @@ sgml_validator_append_internal (gpointer data)
 {
 	SgmlValidatorAppendCBData *append_data;
 
-	g_return_if_fail (data != NULL);
+	g_return_val_if_fail (data != NULL, FALSE);
 
 	append_data = (SgmlValidatorAppendCBData *) data;
 
